/* eslint-env jest */
import { SldsInputCheckbox } from '../input-checkbox';
import * as utils from '../../../../../.jest/utils';
// Register custom element for jest wrapper
customElements.define('slds-input-checkbox', SldsInputCheckbox);

describe('slds-input-text', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });

  it('contains named parts with the values "input-checkbox", "checkbox", "label-container", "indicator", and "label"', async () => {
    const element = utils.renderIntoBody(`<slds-input-checkbox invalid></slds-input-checkbox>`);
    const inputCheckbox = element.shadowRoot.querySelector('[part~="input-checkbox"]');
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    const labelContainer = element.shadowRoot.querySelector('[part~="label-container"]');
    const indicator = element.shadowRoot.querySelector('[part~="indicator"]');
    const label = element.shadowRoot.querySelector('[part~="label"]');

    expect(inputCheckbox).toHaveAttribute('part', 'input-checkbox');
    expect(checkbox).toHaveAttribute('part', 'checkbox');
    expect(labelContainer).toHaveAttribute('part', 'label-container');
    expect(indicator).toHaveAttribute('part', 'indicator');
    expect(label).toHaveAttribute('part', 'label');
  });

  it('contains required indicator if required', async () => {
    const element = utils.renderIntoBody(`<slds-input-checkbox required></slds-input-checkbox>`);
    const elementControl = utils.renderIntoBody(`<slds-input-checkbox></slds-input-checkbox>`);
    const required = element.shadowRoot.querySelector('abbr[title~="required"]');
    const requiredControl = elementControl.shadowRoot.querySelector('abbr[title~="required"]');

    expect(required).toHaveAttribute('title', 'required');
    expect(requiredControl).toBeNull();
  });

  it('contains help text if invalid', async () => {
    const element = utils.renderIntoBody(`<slds-input-checkbox invalid></slds-input-checkbox>`);
    const elementControl = utils.renderIntoBody(`<slds-input-checkbox></slds-input-checkbox>`);
    const helpText = element.shadowRoot.querySelector('[part~="help-text"]');
    const helpTextControl = elementControl.shadowRoot.querySelector('[part~="help-text"]');

    expect(helpText).toHaveAttribute('part', 'help-text');
    expect(helpTextControl).toBeNull();
  });

  it('contains updated markup for label-inline variant', async () => {
    const element = utils.renderIntoBody(
      `<slds-input-checkbox variant="label-inline"></slds-input-checkbox>`,
    );

    // Check if the label-container has been made a sibling of input-checkbox and appears before it
    const checkLabelContainer = element.shadowRoot.querySelector(
      '[part~="label-container"] ~ [part~="input-checkbox"]',
    );
    expect(checkLabelContainer).toBeTruthy();
  });

  it('contains updated markup for label-stacked variant', async () => {
    const element = utils.renderIntoBody(
      `<slds-input-checkbox variant="label-stacked"></slds-input-checkbox>`,
    );

    // Check if the label-container has been made a sibling of input-checkbox and appears before it
    const checkLabelContainer = element.shadowRoot.querySelector(
      '[part~="label-container"] ~ [part~="input-checkbox"]',
    );
    expect(checkLabelContainer).toBeTruthy();
  });

  it('adds assistive text class for label-hidden variant', async () => {
    const element = utils.renderIntoBody(
      `<slds-input-checkbox variant="label-hidden"></slds-input-checkbox>`,
    );

    const label = element.shadowRoot.querySelector('[part~="label"]');
    expect(label).toHaveClass('slds-assistive-text');
  });
});
